"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Editors = void 0;
const autocompleterEditor_js_1 = require("./autocompleterEditor.js");
const checkboxEditor_js_1 = require("./checkboxEditor.js");
const dateEditor_js_1 = require("./dateEditor.js");
const dualInputEditor_js_1 = require("./dualInputEditor.js");
const floatEditor_js_1 = require("./floatEditor.js");
const inputEditor_js_1 = require("./inputEditor.js");
const inputPasswordEditor_js_1 = require("./inputPasswordEditor.js");
const integerEditor_js_1 = require("./integerEditor.js");
const longTextEditor_js_1 = require("./longTextEditor.js");
const multipleSelectEditor_js_1 = require("./multipleSelectEditor.js");
const singleSelectEditor_js_1 = require("./singleSelectEditor.js");
const sliderEditor_js_1 = require("./sliderEditor.js");
exports.Editors = {
    /** Autocompleter Editor (using https://github.com/kraaden/autocomplete) */
    autocompleter: autocompleterEditor_js_1.AutocompleterEditor,
    /** Checkbox Editor (uses native checkbox DOM element) */
    checkbox: checkboxEditor_js_1.CheckboxEditor,
    /** Date Picker Editor (which uses 3rd party lib "vanilla-calendar-pro") */
    date: dateEditor_js_1.DateEditor,
    /** Dual Input Editor, default input type is text but it could be (integer/float/number/password/text) */
    dualInput: dualInputEditor_js_1.DualInputEditor,
    /** Float Number Editor using an input of type "number" */
    float: floatEditor_js_1.FloatEditor,
    /** Integer Number Editor using an input of type "number" */
    integer: integerEditor_js_1.IntegerEditor,
    /**
     * Long Text Editor (uses a textarea) for longer text (you can also optionally configure its size).
     * When ready to Save you can click on the "Save" and/or use shortcuts (Ctrl+ENTER or Ctrl+s).
     */
    longText: longTextEditor_js_1.LongTextEditor,
    /** Multiple Select editor (which uses 3rd party lib "multiple-select.js") */
    multipleSelect: multipleSelectEditor_js_1.MultipleSelectEditor,
    /** Editor with an input of type Password (note that only the text shown in the UI will be masked, the editor value is still plain text) */
    password: inputPasswordEditor_js_1.InputPasswordEditor,
    /** Single Select editor (which uses 3rd party lib "multiple-select.js") */
    singleSelect: singleSelectEditor_js_1.SingleSelectEditor,
    /** Slider Editor using an input of type "range" */
    slider: sliderEditor_js_1.SliderEditor,
    /** text Editor using an input of type "text" (this is the default editor when no type is provided) */
    text: inputEditor_js_1.InputEditor,
};
//# sourceMappingURL=editors.index.js.map