"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Filters = void 0;
const autocompleterFilter_js_1 = require("./autocompleterFilter.js");
const compoundDateFilter_js_1 = require("./compoundDateFilter.js");
const compoundInputFilter_js_1 = require("./compoundInputFilter.js");
const compoundInputNumberFilter_js_1 = require("./compoundInputNumberFilter.js");
const compoundInputPasswordFilter_js_1 = require("./compoundInputPasswordFilter.js");
const compoundSliderFilter_js_1 = require("./compoundSliderFilter.js");
const inputFilter_js_1 = require("./inputFilter.js");
const inputMaskFilter_js_1 = require("./inputMaskFilter.js");
const inputNumberFilter_js_1 = require("./inputNumberFilter.js");
const inputPasswordFilter_js_1 = require("./inputPasswordFilter.js");
const multipleSelectFilter_js_1 = require("./multipleSelectFilter.js");
const dateRangeFilter_js_1 = require("./dateRangeFilter.js");
const singleSelectFilter_js_1 = require("./singleSelectFilter.js");
const singleSliderFilter_js_1 = require("./singleSliderFilter.js");
const sliderRangeFilter_js_1 = require("./sliderRangeFilter.js");
exports.Filters = {
    /** AutoComplete Filter (using https://github.com/kraaden/autocomplete) */
    autocompleter: autocompleterFilter_js_1.AutocompleterFilter,
    /** Compound Date Filter (compound of Operator + Date picker) */
    compoundDate: compoundDateFilter_js_1.CompoundDateFilter,
    /** Alias to compoundInputText to Compound Input Filter (compound of Operator + Input Text) */
    compoundInput: compoundInputFilter_js_1.CompoundInputFilter,
    /** Compound Input Number Filter (compound of Operator + Input of type Number) */
    compoundInputNumber: compoundInputNumberFilter_js_1.CompoundInputNumberFilter,
    /** Compound Input Password Filter (compound of Operator + Input of type Password, also note that only the text shown in the UI will be masked, filter query is still plain text) */
    compoundInputPassword: compoundInputPasswordFilter_js_1.CompoundInputPasswordFilter,
    /** Compound Input Text Filter (compound of Operator + Input Text) */
    compoundInputText: compoundInputFilter_js_1.CompoundInputFilter,
    /** Compound Slider Filter (compound of Operator + Slider) */
    compoundSlider: compoundSliderFilter_js_1.CompoundSliderFilter,
    /** Range Date Filter (uses the Flactpickr Date picker with range option) */
    dateRange: dateRangeFilter_js_1.DateRangeFilter,
    /** Alias to inputText, input type text filter (this is the default filter when no type is provided) */
    input: inputFilter_js_1.InputFilter,
    /**
     * Input Filter of type text that will be formatted with a mask output
     * e.g.: column: { filter: { model: Filters.inputMask }, params: { mask: '(000) 000-0000' }}
     */
    inputMask: inputMaskFilter_js_1.InputMaskFilter,
    /** Input Filter of type Number */
    inputNumber: inputNumberFilter_js_1.InputNumberFilter,
    /** Input Filter of type Password (note that only the text shown in the UI will be masked, filter query is still plain text) */
    inputPassword: inputPasswordFilter_js_1.InputPasswordFilter,
    /** Default Filter, input type text filter */
    inputText: inputFilter_js_1.InputFilter,
    /** Multiple Select filter, which uses 3rd party lib "multiple-select.js" */
    multipleSelect: multipleSelectFilter_js_1.MultipleSelectFilter,
    /** Single Select filter, which uses 3rd party lib "multiple-select.js" */
    singleSelect: singleSelectFilter_js_1.SingleSelectFilter,
    /** Slider Filter (single value) */
    slider: singleSliderFilter_js_1.SingleSliderFilter,
    /** Slider Range Filter (dual values, lowest/highest filter range) */
    sliderRange: sliderRangeFilter_js_1.SliderRangeFilter,
};
//# sourceMappingURL=filters.index.js.map