"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupTotalFormatters = void 0;
const avgTotalsPercentageFormatter_js_1 = require("./avgTotalsPercentageFormatter.js");
const avgTotalsDollarFormatter_js_1 = require("./avgTotalsDollarFormatter.js");
const avgTotalsCurrencyFormatter_js_1 = require("./avgTotalsCurrencyFormatter.js");
const avgTotalsFormatter_js_1 = require("./avgTotalsFormatter.js");
const minTotalsFormatter_js_1 = require("./minTotalsFormatter.js");
const maxTotalsFormatter_js_1 = require("./maxTotalsFormatter.js");
const sumTotalsColoredFormatter_js_1 = require("./sumTotalsColoredFormatter.js");
const sumTotalsCurrencyFormatter_js_1 = require("./sumTotalsCurrencyFormatter.js");
const sumTotalsCurrencyColoredFormatter_js_1 = require("./sumTotalsCurrencyColoredFormatter.js");
const sumTotalsDollarColoredBoldFormatter_js_1 = require("./sumTotalsDollarColoredBoldFormatter.js");
const sumTotalsDollarColoredFormatter_js_1 = require("./sumTotalsDollarColoredFormatter.js");
const sumTotalsDollarBoldFormatter_js_1 = require("./sumTotalsDollarBoldFormatter.js");
const sumTotalsDollarFormatter_js_1 = require("./sumTotalsDollarFormatter.js");
const sumTotalsFormatter_js_1 = require("./sumTotalsFormatter.js");
const sumTotalsBoldFormatter_js_1 = require("./sumTotalsBoldFormatter.js");
/** Provides a list of different Formatters that will change the cell value displayed in the UI */
exports.GroupTotalFormatters = {
    /**
     * Average all the column totals
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    avgTotals: avgTotalsFormatter_js_1.avgTotalsFormatter,
    /**
     * Average all the column totals and display currency prefix/suffix via "groupFormatterCurrencyPrefix" and/or "groupFormatterCurrencySuffix"
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    avgTotalsCurrency: avgTotalsCurrencyFormatter_js_1.avgTotalsCurrencyFormatter,
    /**
     * Average all the column totals and display '$' at the end of the value
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    avgTotalsDollar: avgTotalsDollarFormatter_js_1.avgTotalsDollarFormatter,
    /**
     * Average all the column totals and display '%' at the end of the value
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    avgTotalsPercentage: avgTotalsPercentageFormatter_js_1.avgTotalsPercentageFormatter,
    /**
     * Show max value of all the column totals
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    maxTotals: maxTotalsFormatter_js_1.maxTotalsFormatter,
    /**
     * Show min value of all the column totals
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    minTotals: minTotalsFormatter_js_1.minTotalsFormatter,
    /**
     * Sums up all the column totals
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g.: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotals: sumTotalsFormatter_js_1.sumTotalsFormatter,
    /**
     * Sums up all the column totals and display it in bold font weight
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsBold: sumTotalsBoldFormatter_js_1.sumTotalsBoldFormatter,
    /**
     * Sums up all the column totals, change color of text to red/green on negative/positive value
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsColored: sumTotalsColoredFormatter_js_1.sumTotalsColoredFormatter,
    /**
     * Sums up all the column totals and display currency
     * Extra options available in "params":: "groupFormatterPrefix", "groupFormatterSuffix", "groupFormatterCurrencyPrefix" and/or "groupFormatterCurrencySuffix"
     * e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsCurrency: sumTotalsCurrencyFormatter_js_1.sumTotalsCurrencyFormatter,
    /**
     * Sums up all the column totals and display currency with color of red/green text on negative/positive values
     * Extra options available in "params":: "groupFormatterPrefix", "groupFormatterSuffix", "groupFormatterCurrencyPrefix" and/or "groupFormatterCurrencySuffix"
     * e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsCurrencyColored: sumTotalsCurrencyColoredFormatter_js_1.sumTotalsCurrencyColoredFormatter,
    /**
     * Sums up all the column totals and display dollar sign
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsDollar: sumTotalsDollarFormatter_js_1.sumTotalsDollarFormatter,
    /**
     * Sums up all the column totals and display dollar sign and show it in bold font weight
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsDollarBold: sumTotalsDollarBoldFormatter_js_1.sumTotalsDollarBoldFormatter,
    /**
     * Sums up all the column totals, change color of text to red/green on negative/positive value
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsDollarColored: sumTotalsDollarColoredFormatter_js_1.sumTotalsDollarColoredFormatter,
    /**
     * Sums up all the column totals, change color of text to red/green on negative/positive value, show it in bold font weight as well
     * Extra options available in "params":: "groupFormatterPrefix" and "groupFormatterSuffix", e.g: params: { groupFormatterPrefix: '<i>Total</i>: ', groupFormatterSuffix: '$' }
     */
    sumTotalsDollarColoredBold: sumTotalsDollarColoredBoldFormatter_js_1.sumTotalsDollarColoredBoldFormatter,
};
//# sourceMappingURL=groupingFormatters.index.js.map