import { FieldType } from '../enums/index.js';
/**
 * From a Date FieldType, return it's equivalent TempoJS format,
 * refer to TempoJS docs for the format tokens being used: https://tempo.formkit.com/#format
 * @param {FieldType} fieldType
 * @param { withZeroPadding: [boolean]; withDefaultIso8601: [boolean]; } [options] -
 *   - withZeroPadding: should we include zero padding in format (e.g.: 03:04:54 instead of 3:4:54)
 *   - withDefaultIso8601: should we use ISO8601 for `FieldType.date` or `FieldType.dateIso`
 */
export declare function mapTempoDateFormatWithFieldType(fieldType: (typeof FieldType)[keyof typeof FieldType], options?: {
    withZeroPadding?: boolean;
    withDefaultIso8601?: boolean;
}): string;
/**
 * Format a date using Tempo and a defined input/output field types
 * @param {string|Date} inputDate
 * @param {FieldType} inputFieldType
 * @param {FieldType} outputFieldType
 * @returns
 */
export declare function formatDateByFieldType(inputDate: Date | string, inputFieldType: (typeof FieldType)[keyof typeof FieldType] | undefined, outputFieldType: (typeof FieldType)[keyof typeof FieldType]): string;
/**
 * Try to parse date with Tempo or return `false` (instead of throwing) if Date is invalid.
 * When using strict mode, it will detect if the date is invalid when outside of the calendar (e.g. "2011-11-31").
 * However in non-strict mode, it will roll the date backward if out of calendar (e.g. "2011-11-31" would return "2011-11-30").
 * @param {string|Date} [inputDate] - input date (or null)
 * @param {string} [inputFormat] - optional input format to use when parsing
 * @param {Boolean} [strict] - are we using strict mode?
 * @returns
 */
export declare function tryParseDate(inputDate?: string | Date, inputFormat?: string, strict?: boolean): Date | false;
/**
 * Parse a Date as a UTC date (without local TZ offset)
 * @param inputDate
 * @returns
 */
export declare function toUtcDate(inputDate: string | Date): Date;
/**
 * Parse a date passed as a string (Date only, without time) and return a TZ Date (without milliseconds)
 * @param inputDateString
 * @returns TZ UTC date formatted
 */
export declare function parseUtcDate(inputDateString: string): string;
//# sourceMappingURL=dateUtils.d.ts.map